@@ -1,10 +1,9 @@
 #! /usr/bin/env python
 from __future__ import division
 
-from timeside.decoder import ArrayDecoder
+from timeside.decoder.array import ArrayDecoder
 from unit_timeside import *
 
-
 import numpy as np
 
 
@@ -20,7 +19,6 @@ class TestDecoding(unittest.TestCase):
         self.expected_duration = self.array_duration
         self.expected_is_segment = False
 
-
     def test1DArray(self):
         "Test 1D Array decoding"
         self.source_samplerate = 44100
@@ -28,7 +26,6 @@ class TestDecoding(unittest.TestCase):
             self.array_duration * self.source_samplerate,)
         self.source_channels = 1
 
-
     def test2DArrayMono(self):
         "Test 2D Array mono decoding"
         self.source_samplerate = 32000
@@ -59,7 +56,6 @@ class TestDecoding(unittest.TestCase):
         decoder.setup(samplerate=self.samplerate, channels=self.channels,
                       blocksize=self.blocksize)
 
-
         # Check input
         self.assertEqual(self.source_samplerate, decoder.input_samplerate)
         self.assertEqual(self.expected_is_segment, decoder.is_segment)
@@ -76,7 +72,6 @@ class TestDecoding(unittest.TestCase):
         self.assertIsInstance(decoder.resolution(), int)
         self.assertIsNone(decoder.metadata())
 
-
         totalframes = 0
 
         while True:
@@ -104,8 +99,8 @@ class TestDecoding(unittest.TestCase):
             self.assertEqual(
                 decoder.input_samplerate, decoder.output_samplerate)
 
-
-        self.assertEqual(totalframes, self.expected_duration * decoder.output_samplerate)
+        self.assertEqual(totalframes,
+                         self.expected_duration * decoder.output_samplerate)
         self.assertEquals(totalframes, decoder.totalframes())
 
 
@@ -119,8 +114,6 @@ class TestDecodingSegment(TestDecoding):
         self.expected_duration = self.duration
 
 
-
-
 class TestDecodingSegmentDefaultStart(TestDecodingSegment):
 
     def setUp(self):
