@@ -26,9 +26,12 @@
 #   Guillaume Pellerin <yomguy@parisson.com>
 
 try:
-    from PIL import ImageFilter, ImageChops, Image, ImageDraw, ImageColor, ImageEnhance
+    from PIL import Image, ImageDraw, ImageColor, ImageEnhance
 except ImportError:
-    import ImageFilter, ImageChops, Image, ImageDraw, ImageColor, ImageEnhance
+    import Image
+    import ImageDraw
+    import ImageColor
+    import ImageEnhance
 
 import numpy
 
@@ -42,14 +45,17 @@ def interpolate_colors(colors, flat=False, num_colors=256):
     palette = []
 
     for i in range(num_colors):
-        index = (i * (len(colors) - 1))/(num_colors - 1.0)
+        index = (i * (len(colors) - 1)) / (num_colors - 1.0)
         index_int = int(index)
         alpha = index - float(index_int)
 
         if alpha > 0:
-            r = (1.0 - alpha) * colors[index_int][0] + alpha * colors[index_int + 1][0]
-            g = (1.0 - alpha) * colors[index_int][1] + alpha * colors[index_int + 1][1]
-            b = (1.0 - alpha) * colors[index_int][2] + alpha * colors[index_int + 1][2]
+            r = (1.0 - alpha) * colors[index_int][
+                0] + alpha * colors[index_int + 1][0]
+            g = (1.0 - alpha) * colors[index_int][
+                1] + alpha * colors[index_int + 1][1]
+            b = (1.0 - alpha) * colors[index_int][
+                2] + alpha * colors[index_int + 1][2]
         else:
             r = (1.0 - alpha) * colors[index_int][0]
             g = (1.0 - alpha) * colors[index_int][1]
@@ -71,7 +77,7 @@ def downsample(vector, factor):
     if (len(vector) % factor):
         print "Length of 'vector' is not divisible by 'factor'=%d!" % factor
         return 0
-    vector.shape = (len(vector)/factor, factor)
+    vector.shape = (len(vector) / factor, factor)
     return numpy.mean(vector, axis=1)
 
 
@@ -108,7 +114,7 @@ def smooth(x, window_len=10, window='hanning'):
     --------
 
     >>> import numpy as np
-    >>> from timeside.grapher import smooth
+    >>> from timeside.grapher.utils import smooth
     >>> t = np.arange(-2,2,0.1)
     >>> x = np.sin(t)+np.random.randn(len(t))*0.1
     >>> y = smooth(x)
@@ -122,26 +128,28 @@ def smooth(x, window_len=10, window='hanning'):
     >>> plt.show() # doctest: +SKIP
     """
 
-    # TODO: the window parameter could be the window itself if an array instead of a string
+    # TODO: the window parameter could be the window itself if an array
+    # instead of a string
 
     if x.ndim != 1:
-        raise ValueError, "smooth only accepts 1 dimension arrays."
+        raise ValueError("smooth only accepts 1 dimension arrays.")
     if x.size < window_len:
-        raise ValueError, "Input vector needs to be bigger than window size."
+        raise ValueError("Input vector needs to be bigger than window size.")
     if window_len < 3:
         return x
     if not window in ['flat', 'hanning', 'hamming', 'bartlett', 'blackman']:
-        raise ValueError, "Window is on of 'flat', 'hanning', 'hamming', 'bartlett', 'blackman'"
+        raise ValueError("Window is on of 'flat', 'hanning', 'hamming', 'bartlett', 'blackman'")
 
-    s = numpy.r_[2*x[0]-x[window_len:1:-1], x, 2*x[-1]-x[-1:-window_len:-1]]
+    s = numpy.r_[2 * x[0] - x[window_len:1:-1],
+                 x, 2 * x[-1] - x[-1:-window_len:-1]]
 
-    if window == 'flat': #moving average
-        w = numpy.ones(window_len,'d')
+    if window == 'flat':  # moving average
+        w = numpy.ones(window_len, 'd')
     else:
         w = getattr(numpy, window)(window_len)
 
-    y = numpy.convolve(w/w.sum(), s, mode='same')
-    return y[window_len-1:-window_len+1]
+    y = numpy.convolve(w / w.sum(), s, mode='same')
+    return y[window_len - 1:-window_len + 1]
 
 
 def reduce_opacity(im, opacity):
@@ -157,17 +165,17 @@ def reduce_opacity(im, opacity):
     return im
 
 
-def im_watermark(im, inputtext, font=None, color=None, opacity=.6, margin=(30,30)):
+def im_watermark(im, inputtext, font=None, color=None, opacity=.6, margin=(30, 30)):
     """imprints a PIL image with the indicated text in lower-right corner"""
     if im.mode != "RGBA":
         im = im.convert("RGBA")
-    textlayer = Image.new("RGBA", im.size, (0,0,0,0))
+    textlayer = Image.new("RGBA", im.size, (0, 0, 0, 0))
     textdraw = ImageDraw.Draw(textlayer)
     textsize = textdraw.textsize(inputtext, font=font)
-    textpos = [im.size[i]-textsize[i]-margin[i] for i in [0,1]]
+    textpos = [im.size[i] - textsize[i] - margin[i] for i in [0, 1]]
     textdraw.text(textpos, inputtext, font=font, fill=color)
     if opacity != 1:
-        textlayer = reduce_opacity(textlayer,opacity)
+        textlayer = reduce_opacity(textlayer, opacity)
     return Image.composite(textlayer, im, textlayer)
 
 
@@ -189,7 +197,7 @@ def peaks(samples):
 
 def color_from_value(self, value):
     """ given a value between 0 and 1, return an (r,g,b) tuple """
-    return ImageColor.getrgb("hsl(%d,%d%%,%d%%)" % (int( (1.0 - value) * 360 ), 80, 50))
+    return ImageColor.getrgb("hsl(%d,%d%%,%d%%)" % (int((1.0 - value) * 360), 80, 50))
 
 
 def mean(samples):
@@ -197,5 +205,5 @@ def mean(samples):
 
 
 def normalize(contour):
-    contour = contour-min(contour)
-    return contour/max(contour)
+    contour = contour - min(contour)
+    return contour / max(contour)
